:mod:`API`
----------------------------

``intake-axds`` Python API
=============================

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Documentation


``intake-axds`` catalog
***********************

.. automodule:: intake_axds.axds_cat
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


``intake-axds`` utilities
*************************

.. automodule:: intake_axds.utils
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:
